@@ -74,6 +74,9 @@ class Config(object):
     """Send exceptions to Sentry. Raven must be installed in order that
     this feature to work."""
 
+    SENTRY_PROJECT_URL = None
+    """Sentry project URL. Required to generate links to Sentry in Manager."""
+
     # Connection Options
     ####################
 
@@ -92,6 +95,18 @@ class Config(object):
     RABBIT_PASSWORD = 'guest'
     """RabbitMQ password."""
 
+    REDIS_HOST = 'localhost'
+    """Redis host."""
+
+    REDIS_PORT = 6379
+    """Redis port."""
+
+    REDIS_DB = 0
+    """Redis database."""
+
+    REDIS_PASSWORD = None
+    """Redis password."""
+
     # Manager Options
     #################
 
